import * as express from 'express';
import * as https from 'https';
import * as WebSocket from 'ws';
import * as fs from 'fs';

var privateKey  = fs.readFileSync('certs/key.pem', 'utf8');
var certificate = fs.readFileSync('certs/cert.pem', 'utf8');
var credentials = {key: privateKey, cert: certificate};

const app = express();
const server = https.createServer(credentials, app);
const wss = new WebSocket.Server({ server, maxPayload:250000 });

wss.on('connection', (ws: WebSocket) => {
    console.log('client connected')

    ws.on('message', (message: string) => {

        console.log('received: %s', message);

        const broadcastRegex = /^broadcast\:/;

        if (broadcastRegex.test(message)) {
            message = message.replace(broadcastRegex, '');

            //send back the message to the other clients
            wss.clients
                .forEach(client => {
                    if (client != ws) {
                        client.send(`Hello, broadcast message -> ${message}`);
                    }
                });

        } else {
            ws.send(`Hello, you sent -> ${message}`);
        }
    });

    ws.send('Hi there, welcome to braid, Measures Web Socket server.\nConnecting all our services!');
});

// start our server
server.listen(process.env.PORT || 8443, () => {
    console.log(`Server started :)`);
});

app.get('/', (req, res) => {
  res.send('Braid v0.1.2 is running!\n');
});
